<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Sat Aug 01 2020 15:50:50 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed issue with location being NoneType for TVEpisode objects
  ([78b25830](https://gitlab-ci-token:25ujmAQJn9mjf42U-vrC@git.sickrage.ca/SiCKRAGE/sickrage/commit/78b2583093228cbcd5ab57765d5c6d031d9d373b))




